==> nextcloud-23.0.12p1.tgz: nextcloud/apps/viewer/l10n/nl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Eenvoudige bestand viewer met diavertoning voor media bestanden",
    "Your browser does not support audio." : "Je browser ondersteunt geen audio.",
    "Error loading {name}" : "Fout bij laden van {name}",
    "Image saved" : "Afbeelding opgeslagen",
    "Unsaved changes" : "Niet opgeslagen veranderingen",
    "Your browser does not support videos." : "Je browser ondersteunt geen videos.",
    "Edit" : "Bewerk",
    "Open sidebar" : "Open zijbalk",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "There is no plugin available to display this file type" : "Er is geen plug-in beschikbaar om dit bestandstype weer te geven",
    "View" : "Bekijken",
    "Name" : "Naam",
    "Save" : "Opslaan",
    "Back" : "Terug",
    "Loading …" : "Laden …",
    "Reset" : "Herstellen",
    "Cancel" : "Annuleren",
    "Continue" : "Doorgaan",
    "Undo" : "Ongedaan maken",
    "Redo" : "Opnieuw doen",
    "Zoom in" : "Zoom in",
    "Draw" : "Teken",
    "Original" : "Origineel",
    "Custom" : "Maatwerk",
    "Un-flip X" : "Ontspiegelen X",
    "Value" : "Waarden",
    "Image" : "Afbeelding",
    "Line" : "Lijn",
    "Text" : "Tekst",
    "Size" : "Omvang",
    "Position" : "Positie",
    "Extension" : "Extensie",
    "Name is required." : "Naam is verplicht",
    "Quality" : "Kwaliteit",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Toon je laatste vakantie foto's en videos zoals in de films, toon een deel van je laatste boek direct vanuit je nextcloud, kies de beste GIF uit jouw collectie dankzij de directe voorvertoning van je favoriete bestanden en nog veel meer!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/viewer/l10n/nl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Eenvoudige bestand viewer met diavertoning voor media bestanden",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Toon je laatste vakantie foto's en videos zoals in de films, toon een deel van je laatste boek direct vanuit je nextcloud, kies de beste GIF uit jouw collectie dankzij de directe voorvertoning van je favoriete bestanden en nog veel meer!",
    "Your browser does not support audio." : "Je browser ondersteunt geen audio.",
    "Error loading {name}" : "Fout bij laden van {name}",
    "Unsaved changes" : "Niet opgeslagen veranderingen",
    "Your browser does not support videos." : "Je browser ondersteunt geen videos.",
    "Edit" : "Bewerk",
    "Open sidebar" : "Open zijbalk",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "There is no plugin available to display this file type" : "Er is geen plug-in beschikbaar om dit bestandstype weer te geven",
    "View" : "Bekijken",
    "Name" : "Naam",
    "Save" : "Opslaan",
    "Back" : "Terug",
    "Loading …" : "Laden …",
    "Reset" : "Herstellen",
    "Cancel" : "Annuleren",
    "Continue" : "Doorgaan",
    "Undo" : "Ongedaan maken",
    "Redo" : "Opnieuw doen",
    "Zoom in" : "Zoom in",
    "Draw" : "Teken",
    "Original" : "Origineel",
    "Custom" : "Maatwerk",
    "Value" : "Waarden",
    "Image" : "Afbeelding",
    "Line" : "Lijn",
    "Text" : "Tekst",
    "Size" : "Omvang",
    "Position" : "Positie",
    "Extension" : "Extensie",
    "Name is required." : "Naam is verplicht",
    "Quality" : "Kwaliteit"
},
"nplurals=2; plural=(n != 1);");
